@@ -1,4 +1,4 @@
-from maleo.schemas.resource import Resource, ResourceIdentifier
+from nexo.schemas.resource import Resource, ResourceIdentifier
 
 PATIENT_RESOURCE = Resource(
     identifiers=[ResourceIdentifier(key="patient", name="Patient", slug="patients")],
