@@ -1,4 +1,4 @@
-from maleo.schemas.resource import Resource, ResourceIdentifier
+from nexo.schemas.resource import Resource, ResourceIdentifier
 
 SESSION_RESOURCE = Resource(
     identifiers=[ResourceIdentifier(key="session", name="Session", slug="sessions")],
